# eric7.MultiProject.AddProjectDialog

Module implementing the add project dialog.

### Global Attributes

None

### Classes

AddProjectDialog | Class implementing the add project dialog.

### Functions

None

## AddProjectDialog

Class implementing the add project dialog.

### Derived from

QDialog, Ui_AddProjectDialog

### Class Attributes

None

### Class Methods

None

### Methods

AddProjectDialog | Constructor
__getFileName | Private method to get the file name of the project file.
__updateUi | Private method to update the dialog.
getProjectMetadata | Public method to get the entered project metadata.
on_filenamePicker_textChanged | Private slot called when the project filename has changed.
on_nameEdit_textChanged | Private slot called when the project name has changed.

### Static Methods

None

#### AddProjectDialog (Constructor)

AddProjectDialog(parent=None, startdir="", project=None, categories=None, category="")

Constructor

parent (QWidget)
  parent widget of this dialog
startdir (str)
  start directory for the selection dialog
project (MultiProjectProjectMeta)
  dictionary containing project metadata
categories (list of str)
  list of already used categories
category (str)
  category to be preset

#### AddProjectDialog.__getFileName

__getFileName()

Private method to get the file name of the project file.

Return:
  project file name

Return Type:
  str

#### AddProjectDialog.__updateUi

__updateUi()

Private method to update the dialog.

#### AddProjectDialog.getProjectMetadata

getProjectMetadata()

Public method to get the entered project metadata.

Return:
  project metadata iaw. the entered values

Return Type:
  MultiProjectProjectMeta

#### AddProjectDialog.on_filenamePicker_textChanged

on_filenamePicker_textChanged(_txt)

Private slot called when the project filename has changed.

_txt (str)
  text of the edit (unused)

#### AddProjectDialog.on_nameEdit_textChanged

on_nameEdit_textChanged(_txt)

Private slot called when the project name has changed.

_txt (str)
  text of the edit (unused)

Up